/* 
 * AppController.h created by phr on 2000-08-27 11:38:59 +0000
 *
 * Project TestApp
 *
 * Created with ProjectCenter - http://www.gnustep.org
 *
 * $Id: AppController.h,v 1.1.1.1 2001/12/30 12:42:37 probert Exp $
 */

#import <AppKit/AppKit.h>

@class Command;

@interface AppController : NSObject
{
    NSTimeInterval interval;
    NSTimer        *timer;

    NSTextField    *timeField;
    NSTextField    *commandField;
    NSTextView     *output;
    NSButton       *activeButton;
    NSWindow       *window;
    Command        *command;
}

+ (void)initialize;

- (id)init;
- (void)dealloc;

- (void)awakeFromNib;

- (void)applicationDidFinishLaunching:(NSNotification *)notif;

- (BOOL)applicationShouldTerminate:(id)sender;
- (void)applicationWillTerminate:(NSNotification *)notification;

- (BOOL)application:(NSApplication *)application openFile:(NSString *)fileName;

- (void)showPrefPanel:(id)sender;
- (void)showInfoPanel:(id)sender;

- (void)setCommand:(id)sender;
- (void)setTimeInterval:(id)sender;
- (void)activateCommand:(id)sender;
- (void)executeCommand;

@end
