/* 
 * Command.h created by probert on 2001-12-29 17:36:44 +0000
 *
 * Project GSCommander
 *
 * Created with ProjectCenter - http://www.gnustep.org
 *
 * $Id: Command.h,v 1.1.1.1 2001/12/30 12:42:37 probert Exp $
 */

#ifndef _COMMAND_H_
#define _COMMAND_H_

#import <AppKit/AppKit.h>

@interface Command : NSObject
{
    NSString *command;
    NSTask *task;
    NSMutableArray *args;
    NSPipe *pipe;
    NSFileHandle *fileHandle;
    NSTextView *output;
}

- (id)initWithCommand:(NSString *)comm args:(NSArray *)arguments;
- (void)dealloc;

- (void)setTextView:(NSTextView *)view;

- (void)log:(NSNotification *)aNotif;
- (void)executeCommand;
- (void)stop;

@end

#endif // _COMMAND_H_

